# <font color=Green>**Citation**</font>

## <font color=Green>**Please cite PyExoCross paper &#x1F49A;**</font> 

PyExoCross ***published paper*** : [https://doi.org/10.1093/rasti/rzae016](https://doi.org/10.1093/rasti/rzae016)

PyExoCross ***arXiv preprint*** : [https://arxiv.org/abs/2406.03977](https://arxiv.org/abs/2406.03977)

<font color=Green>***Cite***</font>

Jingxin Zhang, Jonathan Tennyson, Sergei N Yurchenko, 
PyExoCross: a Python program for generating spectra and cross-sections from molecular line lists, 
*RAS Techniques and Instruments*, Volume 3, Issue 1, January 2024, Pages 257–287, 
https://doi.org/10.1093/rasti/rzae016

<font color=Green>***Bibtex***</font>

```bash
@article{10.1093/rasti/rzae016,
    author   = {Zhang, Jingxin and Tennyson, Jonathan and Yurchenko, Sergei N},
    title    = {{PyExoCross: a Python program for generating spectra and cross-sections from molecular line lists}},
    journal  = {RAS Techniques and Instruments},
    volume   = {3},
    number   = {1},
    pages    = {257-287},
    year     = {2024},
    month    = {04},
    abstract = {PyExoCross is a Python adaptation of the ExoCross Fortran application, 
                PyExoCross is designed for post-processing the huge molecular line lists generated by the ExoMol project 
                and other similar initiatives such as the HITRAN and HITEMP data bases. 
                PyExoCross generates absorption and emission stick spectra, cross-sections, and other properties 
                (partition functions, specific heats, cooling functions, lifetimes, and oscillator strengths) 
                based on molecular line lists. PyExoCross calculates cross-sections with four line profiles: 
                Doppler, Gaussian, Lorentzian, and Voigt profiles in both sampling and binned methods; 
                a number of options are available for computing Voigt profiles which we test for speed and accuracy. 
                PyExoCross supports importing and exporting line lists in the ExoMol and HITRAN/HITEMP formats. 
                PyExoCross also provides conversion between the ExoMol and HITRAN data formats. 
                In addition, PyExoCross has extra code for users to automate the batch download of 
                line list files from the ExoMol data base.},
    issn     = {2752-8200},
    doi      = {10.1093/rasti/rzae016},
    url      = {https://doi.org/10.1093/rasti/rzae016},
    eprint   = {https://academic.oup.com/rasti/article-pdf/3/1/257/61224370/rzae016.pdf},
}
```